@@ -20,6 +20,18 @@
 # with this application; if not, write to the Free Software Foundation, Inc., 51
 # Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
+####################
+# Type dictionaries: different installation types possible
+def get_install_type_dictionary(self):
+    list= {
+        "Master Backend/Frontend" : self.master_be_fe,                         \
+        "Slave Backend/Frontend"  : self.slave_be_fe,                          \
+        "Master Backend"          : self.master_be,                            \
+        "Slave Backend"           : self.slave_be,                             \
+        "Frontend"                : self.fe,                                   \
+        "Set Top Box"             : self.stb }
+    return list
+
 ####################
 #Theme dictionaries: these are for managing a list of all possible themes
 ####################
@@ -47,6 +59,8 @@ def get_community_theme_dictionary(self):
         "mythtv-theme-glass-wide": self.theme_glass_wide,                      \
         "mythtv-theme-mythbuntu": self.theme_mythbuntu,                        \
         "mythtv-theme-neon-wide": self.theme_neon_wide,                        \
+        "mythtv-theme-metallurgy-wide": self.theme_metallurgy_wide,            \
+        "mythtv-theme-metallurgy-osd": self.theme_metallurgy_osd,              \
         "mythtv-theme-projectgrayhem": self.theme_project_grayhem,             \
         "mythtv-theme-projectgrayhem-osd": self.theme_project_grayhem_osd,     \
         "mythtv-theme-projectgrayhem-wide": self.theme_project_grayhem_wide }
@@ -57,58 +71,72 @@ def get_community_theme_dictionary(self):
 ####################
 def get_frontend_plugin_dictionary(self):
     list = {
-        "mytharchive": self.mytharchive_checkbox,                             \
-        "mythbrowser": self.mythbrowser_checkbox,                             \
-        "mythcontrols": self.mythcontrols_checkbox,                           \
-        "mythflix": self.mythflix_checkbox,                                   \
-        "mythgame": self.mythgame_checkbox,                                   \
-        "mythgallery": self.mythgallery_checkbox,                             \
-        "mythmovies": self.mythmovies_checkbox,                               \
-        "mythmusic": self.mythmusic_checkbox,                                 \
-        "mythnews": self.mythnews_checkbox,                                   \
-        "mythstream":self.mythstream_checkbox,                                \
-        "mythphone": self.mythphone_checkbox,                                 \
-        "mythvideo": self.mythvideo_checkbox,                                 \
-        "mythweather": self.mythweather_checkbox }
+        "mytharchive": self.mytharchive_checkbox,                              \
+        "mythbrowser": self.mythbrowser_checkbox,                              \
+        "mythcontrols": self.mythcontrols_checkbox,                            \
+        "mythflix": self.mythflix_checkbox,                                    \
+        "mythgame": self.mythgame_checkbox,                                    \
+        "mythgallery": self.mythgallery_checkbox,                              \
+        "mythmovies": self.mythmovies_checkbox,                                \
+        "mythmusic": self.mythmusic_checkbox,                                  \
+        "mythnews": self.mythnews_checkbox,                                    \
+        "mythstream":self.mythstream_checkbox,                                 \
+        "mythphone": self.mythphone_checkbox,                                  \
+        "mythvideo": self.mythvideo_checkbox,                                  \
+        "mythweather": self.mythweather_checkbox,                              \
+        "mythbuntu-apple-trailers": self.mb_apple_trailers_checkbox }
     return list
 
 def get_backend_plugin_dictionary(self):
     return { "mythweb": self.mythweb_checkbox }
 
+####################
 #Other dictionaries: these are for managing a list of all other apps
+####################
 def get_desktop_dictionary(self):
     list = {
-        "ubuntu-desktop": self.ubuntu_desk_check,                             \
-        "xubuntu-desktop": self.xubuntu_desk_check,                           \
+        "ubuntu-desktop": self.ubuntu_desk_check,                              \
+        "xubuntu-desktop": self.xubuntu_desk_check,                            \
         "kubuntu-desktop": self.kubuntu_desk_check }
     return list
 
 def get_media_app_dictionary(self):
     list = {
-        "mplayer": self.mplayer_checkbox,                                     \
-        "xine-ui": self.xine_checkbox,                                        \
+        "mplayer": self.mplayer_checkbox,                                      \
+        "xine-ui": self.xine_checkbox,                                         \
         "vlc":  self.vlc_checkbox }
     return list
 
 def get_nonfree_dictionary(self):
     list = {
-        "libdvdcss2": self.enable_libdvdcss2,                                 \
-        "ffmpeg": self.enable_ffmpeg,                                         \
-        "w64codecs": self.enable_w64codecs,                                   \
+        "libdvdcss2": self.enable_libdvdcss2,                                  \
+        "ffmpeg": self.enable_ffmpeg,                                          \
+        "w64codecs": self.enable_w64codecs,                                    \
         "w32codecs": self.enable_w32codecs }
     return list
 
 def get_services_dictionary(self):
     list = {
-        "x11vnc": self.enablevnc,                                         \
-        "samba": self.enablesamba,                                            \
-        "nfs-kernel-server": self.enablenfs,                                  \
-        "openssh-server": self.enablessh,                                     \
+        "x11vnc": self.enablevnc,                                              \
+        "samba": self.enablesamba,                                             \
+        "nfs-kernel-server": self.enablenfs,                                   \
+        "openssh-server": self.enablessh,                                      \
         "mysql-server": self.enablemysql }
     return list
-    
+
 def get_diskless_dictionary(self):
-	list = {
-		"mythbuntu-diskless-server": self.diskless_server_install,          \
+    list = {
+        "mythbuntu-diskless-server": self.diskless_server_install,             \
         "dhcp3-server": self.diskless_server_dhcp }
-	return list
+    return list
+
+
+def get_graphics_dictionary():
+    list =  {
+#        "NVIDIA 71 Series" : "nvidia-glx-71", \
+#        "NVIDIA 96 Series" : "nvidia-glx-96", \
+        "NVIDIA 173 Series" : "nvidia-glx-173", \
+        "NVIDIA 177 Series" : "nvidia-glx-177", \
+        "AMD Proprietary" : "xorg-driver-fglrx", \
+        "Hauppauge PVR-350 (ivtv)" : "xserver-xorg-video-ivtv" }
+    return list
